#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-asn1-encoding
version:              0.10.0
visibility:           public
id:                   crypton-asn1-encoding-0.10.0-FCzbdev5aqgKYAy96nxiDy
key:                  crypton-asn1-encoding-0.10.0-FCzbdev5aqgKYAy96nxiDy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/mpilgrem/crypton-asn1
synopsis:             ASN.1 data (raw, BER or DER) readers and writers
description:
    A library providing readers and writers of data following the Abstract Syntax
    Notation One (ASN.1) standard in raw form or in the high-level forms of Basic
    Encoding Rules (BER) and Distinguished Encoding Rules (DER).

category:             Data
abi:                  00c5317d2f3737b85587482b941773f4
exposed:              True
exposed-modules:
    Data.ASN1.BinaryEncoding, Data.ASN1.BinaryEncoding.Raw,
    Data.ASN1.Encoding, Data.ASN1.Error, Data.ASN1.Prim,
    Data.ASN1.Stream from crypton-asn1-types-0.4.1-9WxX8ChAfOP72KS7XCXVug:Data.ASN1.Stream,
    Data.ASN1.Types from crypton-asn1-types-0.4.1-9WxX8ChAfOP72KS7XCXVug:Data.ASN1.Types

hidden-modules:
    Data.ASN1.BinaryEncoding.Parse Data.ASN1.BinaryEncoding.Writer
    Data.ASN1.Get Data.ASN1.Internal Data.ASN1.Serialize

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-asn1-encoding-0.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-asn1-encoding-0.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-asn1-encoding-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-asn1-encoding
hs-libraries:         HScrypton-asn1-encoding-0.10.0-FCzbdev5aqgKYAy96nxiDy
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    crypton-asn1-types-0.4.1-9WxX8ChAfOP72KS7XCXVug
    time-hourglass-0.3.0-3seSJvdcpIC8dw1iefZkLR

haddock-interfaces:
    /usr/share/doc/haskell-crypton-asn1-encoding/html/crypton-asn1-encoding.haddock

haddock-html:         /usr/share/doc/haskell-crypton-asn1-encoding/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

